==> darcs_2.8.4.orig.tar.gz: darcs-2.8.4/tests/failing-issue2100-add-failures.sh <==
#!/usr/bin/env bash
## Test for issue2100 - darcs add should not fail on first failure
##
## Copyright (C) 2011 Eric Kow 
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib                           # Load some portability helpers.
darcs init      --repo R        # Create our test repos.

cd R
mkdir d
echo 'Example content.' > d/f
not darcs add d/non-existent
not darcs whatsnew
not darcs add d/non-existent d/f
darcs whatsnew > log2 2>&1
grep "./d/non-existent does not exist" log2
not grep "addfile ./d/non-existent" log2
grep "adddir ./d" log2
grep "addfile ./d/f" log2

==> darcs_2.18.4.orig.tar.gz: darcs-2.18.4/tests/failing-issue2100-add-failures.sh <==
#!/usr/bin/env bash
## Test for issue2100 - darcs add should not fail on first failure
##
## Copyright (C) 2011 Eric Kow 
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib                           # Load some portability helpers.
darcs init      --repo R        # Create our test repos.

cd R
mkdir d
echo 'Example content.' > d/f
not darcs add d/non-existent
not darcs whatsnew
not darcs add d/non-existent d/f  > log1 2>&1
darcs whatsnew > log2 2>&1
grep "./d/non-existent does not exist" log1
not grep "addfile ./d/non-existent" log2
grep "adddir ./d" log2
grep "addfile ./d/f" log2
